@@ -20,11 +20,11 @@ Boston, MA 02110-1301 USA
 
 import logging
 import os
-import sys
 
 import gi
-gi.require_version('Gtk', '3.0')
-gi.require_version('Vte', '2.91')  # vte-0.38
+
+gi.require_version("Gtk", "3.0")
+gi.require_version("Vte", "2.91")  # vte-0.38
 from gi.repository import Gtk
 
 from guake.paths import GLADE_DIR
@@ -33,20 +33,22 @@ from guake.paths import IMAGE_DIR
 log = logging.getLogger(__name__)
 
 __all__ = [
-    'get_binaries_from_path',
-    'gladefile',
-    'hexify_color',
-    'pixmapfile',
-    'ShowableError',
+    "get_binaries_from_path",
+    "gladefile",
+    "hexify_color",
+    "pixmapfile",
+    "ShowableError",
 ]
 
 
 def ShowableError(parent, title, msg, exit_code=1):
     d = Gtk.MessageDialog(
-        parent, Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-        Gtk.MessageType.WARNING, Gtk.ButtonsType.CLOSE
+        parent,
+        Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
+        Gtk.MessageType.WARNING,
+        Gtk.ButtonsType.CLOSE,
     )
-    d.set_markup('<b><big>%s</big></b>' % title)
+    d.set_markup(f"<b><big>{title}</big></b>")
     d.format_secondary_markup(msg)
     d.run()
     d.destroy()
@@ -55,28 +57,27 @@ def ShowableError(parent, title, msg, exit_code=1):
 def pixmapfile(x):
     f = os.path.join(IMAGE_DIR, x)
     if not os.path.exists(f):
-        raise IOError('No such file or directory: %s' % f)
+        raise IOError(f"No such file or directory: {f}")
     return os.path.abspath(f)
 
 
 def gladefile(x):
     f = os.path.join(GLADE_DIR, x)
     if not os.path.exists(f):
-        raise IOError('No such file or directory: %s' % f)
+        raise IOError(f"No such file or directory: {f}")
     return os.path.abspath(f)
 
 
 def hexify_color(c):
-
     def h(x):
-        return hex(x).replace('0x', '').zfill(4)
+        return hex(x).replace("0x", "").zfill(4)
 
-    return '#%s%s%s' % (h(c.red), h(c.green), h(c.blue))
+    return f"#{h(c.red)}{h(c.green)}{h(c.blue)}"
 
 
 def get_binaries_from_path(compiled_re):
     ret = []
-    for i in os.environ.get('PATH', '').split(os.pathsep):
+    for i in os.environ.get("PATH", "").split(os.pathsep):
         if os.path.isdir(i):
             for j in os.listdir(i):
                 if compiled_re.match(j):
@@ -85,8 +86,8 @@ def get_binaries_from_path(compiled_re):
 
 
 def shell_quote(text):
-    """ quote text (filename) for inserting into a shell """
-    return r"\'".join("'%s'" % p for p in text.split("'"))
+    """quote text (filename) for inserting into a shell"""
+    return r"\'".join(f"'{p}'" for p in text.split("'"))
 
 
 def clamp(value, lower, upper):
